package com.yanzhu.jh.wxsetting.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.wxsetting.domain.SurMenuConfig;
import com.yanzhu.jh.wxsetting.service.ISurMenuConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 菜单配置Controller
 * 
 * @author JiangYuQi
 * @date 2023-08-24
 */
@RestController
@RequestMapping("/wxsetting/wxMenConfig")
public class SurMenuConfigController extends BaseController
{
    @Autowired
    private ISurMenuConfigService surMenuConfigService;

    /**
     * 查询菜单配置列表
     */
    @PreAuthorize("@ss.hasPermi('wxsetting:wxMenConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(SurMenuConfig surMenuConfig)
    {
        startPage();
        List<SurMenuConfig> list = surMenuConfigService.selectSurMenuConfigList(surMenuConfig);
        return getDataTable(list);
    }

    /**
     * 导出菜单配置列表
     */
    @PreAuthorize("@ss.hasPermi('wxsetting:wxMenConfig:export')")
    @Log(title = "菜单配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SurMenuConfig surMenuConfig)
    {
        List<SurMenuConfig> list = surMenuConfigService.selectSurMenuConfigList(surMenuConfig);
        ExcelUtil<SurMenuConfig> util = new ExcelUtil<SurMenuConfig>(SurMenuConfig.class);
        util.exportExcel(response, list, "菜单配置数据");
    }

    /**
     * 获取菜单配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('wxsetting:wxMenConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surMenuConfigService.selectSurMenuConfigById(id));
    }

    /**
     * 新增菜单配置
     */
    @PreAuthorize("@ss.hasPermi('wxsetting:wxMenConfig:add')")
    @Log(title = "菜单配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SurMenuConfig surMenuConfig)
    {
        return toAjax(surMenuConfigService.insertSurMenuConfig(surMenuConfig));
    }

    /**
     * 修改菜单配置
     */
    @PreAuthorize("@ss.hasPermi('wxsetting:wxMenConfig:edit')")
    @Log(title = "菜单配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SurMenuConfig surMenuConfig)
    {
        return toAjax(surMenuConfigService.updateSurMenuConfig(surMenuConfig));
    }

    /**
     * 删除菜单配置
     */
    @PreAuthorize("@ss.hasPermi('wxsetting:wxMenConfig:remove')")
    @Log(title = "菜单配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surMenuConfigService.deleteSurMenuConfigByIds(ids));
    }
}
